@@ -1,4 +1,4 @@
-derivQfun=function(est,fix.nugget=T){
+derivQfun=function(est,fix.nugget=TRUE){
 
   if(class(est)!="SAEMSpatialCens") stop("an object of the class SAEMSpatialCens must be provided")
   if(!is.logical(fix.nugget)) stop("fix.nugget must be TRUE or FALSE")
@@ -7,4 +7,4 @@ derivQfun=function(est,fix.nugget=T){
 
   return(list(Qlogvalue=out$Qlogvalue,gradQ=out$gradQ,HQ=out$HQ,QI=out$QI,Sigma=out$Sigma))
 
-}
\ No newline at end of file
+}
